aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/com/jogamp/gluegen
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/com/jogamp/gluegen')
-rw-r--r--src/java/com/jogamp/gluegen/pcpp/PCPP.java12
1 files changed, 11 insertions, 1 deletions
diff --git a/src/java/com/jogamp/gluegen/pcpp/PCPP.java b/src/java/com/jogamp/gluegen/pcpp/PCPP.java
index 987d0a9..95a4b43 100644
--- a/src/java/com/jogamp/gluegen/pcpp/PCPP.java
+++ b/src/java/com/jogamp/gluegen/pcpp/PCPP.java
@@ -422,7 +422,17 @@ public class PCPP {
handleInclude();
shouldPrint = false;
} else {
- // Unknown preprocessor directive (#pragma?) -- ignore
+ int line = -1;
+ try {
+ // try '# <line> "<filename>"' case
+ line = Integer.parseInt(w);
+ String filename = nextWordOrString();
+ print("# " + line + " " + filename);
+ println();
+ shouldPrint = false;
+ } catch (NumberFormatException nfe) {
+ // Unknown preprocessor directive (#pragma?) -- ignore
+ }
}
if (shouldPrint) {
print("# ");